===================
Welcome to gridjug!
===================

.. only:: not latex

   .. include:: about-include.rst

Table of Contents
-----------------

.. toctree::
   :maxdepth: 2

   About <about>
   Setup <setup>
   User Guide <user>
   Developer Guide <developer>
   Reference <reference/gridjug>
